@@ -1,3 +1,5 @@
+use crate::Row;
+
 pub trait Table {
     fn table_name() -> &'static str;
     fn table_name_snake() -> String;
@@ -6,13 +8,13 @@ pub trait Table {
 
 /// Scan trait must be impl macro
 pub trait Scan<Table> {
-    fn scan(&mut self) -> crate::Result<Table>;
+    fn scan(self) -> crate::Result<Table>;
 }
 
-/// Scan trait must be impl macro
-pub trait Scans<Table> {
-    fn scan(&mut self) -> crate::Result<Vec<Table>>;
-}
+// /// Scan trait must be impl macro
+// pub trait Scans<Table> {
+//     fn scan(self) -> crate::Result<Vec<Table>>;
+// }
 
 /// impl scan for table struct
 /// for example:
@@ -31,32 +33,68 @@ pub trait Scans<Table> {
 /// ```
 #[macro_export]
 macro_rules! impl_scan {
-    ($db_row:path,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
-    impl $crate::scan::Table for $table{
-    fn table_name() -> &'static str {
-        stringify!($table)
-    }
-    fn table_name_snake() -> String {
-        $crate::to_snake_name(stringify!($table))
-    }
-    fn table_columns() -> &'static [&'static str] {
-        &[$(stringify!($field_name),)+]
-     }
-   }
-
-    impl $crate::scan::Scan<$table> for $db_row{
-      fn scan(&mut self) -> cdbc::Result<$table> {
-          $crate::row_scan!(self,$table { $($field_name:$field_value,)+})
-      }
-    }
-    impl $crate::scan::Scans<$table> for Vec<$db_row>{
-      fn scan(&mut self) -> cdbc::Result<Vec<$table>> {
-          $crate::row_scans!(self,$table { $($field_name:$field_value,)+})
+    ($row_type:path,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
+    impl $crate::scan::Scan<$table> for $row_type{
+      fn scan(self) -> $crate::Result<$table> {
+           let mut table = {
+             $table {
+               $(
+                    $field_name:$field_value,
+               )+
+             }
+           };
+           use $crate::Row;
+           use $crate::column::Column;
+           use $crate::value::ValueRef;
+           for _column in self.columns(){
+             $(
+                  if stringify!($field_name).trim_start_matches("r#").eq(_column.name()){
+                     let r = self.try_get_raw(_column.name())?;
+                     table.$field_name = r.decode()?;
+                   }
+             )+
+           }
+           $crate::Result::Ok(table)
       }
     }
   };
 }
 
+impl<R: Row + Scan<T>, T> Scan<Vec<T>> for Vec<R> {
+    fn scan(self) -> crate::Result<Vec<T>> {
+        let mut result_datas = vec![];
+        for r in self {
+            let table = Scan::<T>::scan(r)?;
+            result_datas.push(table);
+        }
+        Ok(result_datas)
+    }
+}
+
+impl<R: Row + Scan<T>, T> Scan<T> for crate::Result<R> {
+    fn scan(self) -> crate::Result<T> {
+        match self{
+            Ok(v) => {
+                Ok(v.scan()?)
+            }
+            Err(e) => {
+                Err(e)
+            }
+        }
+    }
+}
+
+impl<R: Row + Scan<T>, T> Scan<Vec<T>> for crate::Result<Vec<R>> {
+    fn scan(self) -> crate::Result<Vec<T>> {
+        let mut result_datas = vec![];
+        for r in self? {
+            let table = Scan::<T>::scan(r)?;
+            result_datas.push(table);
+        }
+        Ok(result_datas)
+    }
+}
+
 
 /// scan CDBC Row to an Table,return cdbc::Result<Table>
 /// for example:
@@ -78,28 +116,28 @@ macro_rules! impl_scan {
 ///    }
 #[macro_export]
 macro_rules! row_scan {
-    ($row:expr,$target:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
+    ($row:expr,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
         {
             //logic code
-        let mut table = {
-            $target {
+           let mut table = {
+             $table {
                $(
                     $field_name:$field_value,
                )+
-            }
-        };
-        let row = $row;
-        use cdbc::row::Row;
-        for _column in row.columns(){
-             use cdbc::row::Row;use cdbc::column::Column;
+             }
+           };
+           use $crate::Row;
+           use $crate::column::Column;
+           use $crate::value::ValueRef;
+           for _column in $row.columns(){
              $(
                   if stringify!($field_name).trim_start_matches("r#").eq(_column.name()){
-                     let v = row.try_get_raw(_column.name())?;
-                     table.$field_name = cdbc::decode::Decode::decode(v)?;
+                     let v = $row.try_get_raw(_column.name())?;
+                     table.$field_name = v.decode()?;
                    }
              )+
-        }
-          cdbc::Result::Ok(table)
+           }
+           $crate::Result::Ok(table)
         }
     }
 }
@@ -117,14 +155,14 @@ macro_rules! row_scan {
 ///    let biz_activitys = cdbc::row_scans!(rows,BizActivity{id: None,name: None,delete_flag: None})
 #[macro_export]
 macro_rules! row_scans {
-   ($rows:expr,$target:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
+   ($rows:expr,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
         {
            let mut result_datas = vec![];
            for r in $rows{
-             let table = cdbc::row_scan!(r, $target { $($field_name:$field_value,)+})?;
+             let table = $crate::row_scan!(r, $table { $($field_name:$field_value,)+})?;
              result_datas.push(table);
            }
-          cdbc::Result::Ok(result_datas)
+          $crate::Result::Ok(result_datas)
         }
    }
 }
\ No newline at end of file
